Module snow::error [−][src]
All error types used by Snow operations.
Enums
| InitStage |
The various stages of initialization used to help identify
the specific cause of an |
| PatternProblem |
The various stages of initialization used to help identify
the specific cause of an |
| Prerequisite |
A prerequisite that may be missing. |
| SnowError |
All errors in snow will return a |
| StateProblem |
Specific errors in the state machine. |