pub enum InitStage {
ValidateKeyLengths,
ValidatePskLengths,
ValidateCipherTypes,
GetRngImpl,
GetDhImpl,
GetCipherImpl,
GetHashImpl,
ValidatePskPosition,
ParameterOverwrite,
}Expand description
The various stages of initialization used to help identify
the specific cause of an Init error.
Variants
ValidateKeyLengths
Provided and received key lengths were not equal.
ValidatePskLengths
Provided and received preshared key lengths were not equal.
ValidateCipherTypes
Two separate cipher algorithms were initialized.
GetRngImpl
The RNG couldn’t be initialized.
GetDhImpl
The DH implementation couldn’t be initialized.
GetCipherImpl
The cipher implementation couldn’t be initialized.
GetHashImpl
The hash implementation couldn’t be initialized.
ValidatePskPosition
The PSK position (specified in the pattern string) isn’t valid for the given handshake type.
ParameterOverwrite
The Builder already has set a value for this parameter, and overwrites are not allowed as they can introduce subtle security issues.